==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/admin/messages/sv/modules.php <==
<?php
return array (
  '%moduleName% - Set as default module' => '%moduleName% - Ange som standardmodul',
  '<strong>General</strong> Settings' => '',
  '<strong>Module</strong> details' => '<strong>Modul</strong> detaljer',
  'Activate' => 'Aktivera',
  'Activated' => 'Aktiverad',
  'Allow module versions in beta status' => '',
  'Always activated' => 'Alltid aktiverad',
  'Are you sure? *ALL* module data will be lost!' => 'Är du säker? *ALL* moduldata kommer att gå förlorad!',
  'Are you sure? *ALL* module related data and files will be lost!' => 'Är du säker? *ALLA* modulrelaterade data och filer kommer att gå förlorad!',
  'Close' => 'Stäng',
  'Configure' => 'Konfigurera',
  'Could not find requested module!' => 'Kunde inte hitta begärda modulen!',
  'Deactivated' => 'Inaktiverad',
  'Deprecated' => '',
  'Enable module...' => 'Aktivera modul...',
  'Featured' => '',
  'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Här kan du välja om en modul ska aktiveras automatiskt på ett utrymme eller en användarprofil. Om modulen ska aktiveras, välj "alltid aktiverad".',
  'Installed' => 'Installerad',
  'License not found or expired. Please contact the module publisher.' => 'Licensen hittades inte eller har löpt ut. Kontakta modulutgivaren.',
  'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
  'Module path %path% is not writeable!' => 'Modul sökvägen %path% är inte skrivbar!',
  'New' => 'Ny',
  'No modules found.' => '',
  'Not Installed' => '',
  'Official' => '',
  'Partner' => '',
  'Professional Edition' => '',
  'Save' => 'Spara',
  'Space default state' => '',
  'Spaces' => 'Forum',
  'This module doesn\'t provide further information.' => 'Denna modul ger ingen ytterligare information.',
  'Try other keywords or remove filters.' => 'Prova andra sökord eller ta bort filter.',
  'Update successful' => '',
  'User default state' => '',
  'Users' => 'Användare',
);

==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/admin/messages/sv/modules.php <==
<?php
return array (
  '%moduleName% - Set as default module' => '%moduleName% - Ange som standardmodul',
  '<strong>General</strong> Settings' => '',
  '<strong>Module</strong> details' => '<strong>Modul</strong> detaljer',
  'Activate' => 'Aktivera',
  'Activated' => 'Aktiverad',
  'Allow module versions in beta status' => '',
  'Always activated' => 'Alltid aktiverad',
  'Are you sure? *ALL* module data will be lost!' => 'Är du säker? *ALL* moduldata kommer att gå förlorad!',
  'Are you sure? *ALL* module related data and files will be lost!' => 'Är du säker? *ALLA* modulrelaterade data och filer kommer att gå förlorad!',
  'Close' => 'Stäng',
  'Configure' => 'Konfigurera',
  'Could not find requested module!' => 'Kunde inte hitta begärda modulen!',
  'Deactivated' => 'Inaktiverad',
  'Deprecated' => '',
  'Enable module...' => 'Aktivera modul...',
  'Featured' => 'Utvalda',
  'Here you can choose whether or not a module should be automatically activated on a space or user profile. If the module should be activated, choose "always activated".' => 'Här kan du välja om en modul ska aktiveras automatiskt på ett utrymme eller en användarprofil. Om modulen ska aktiveras, välj "alltid aktiverad".',
  'Installed' => 'Installerad',
  'License not found or expired. Please contact the module publisher.' => 'Licensen hittades inte eller har löpt ut. Kontakta modulutgivaren.',
  'Module "{moduleName}" has been updated to version {newVersion} successfully.' => '',
  'Module path %path% is not writeable!' => 'Modul sökvägen %path% är inte skrivbar!',
  'New' => 'Ny',
  'No modules found.' => '',
  'Not Installed' => 'Inte installerad',
  'Official' => 'Officiell',
  'Partner' => 'Partner',
  'Professional Edition' => 'Professionell version',
  'Save' => 'Spara',
  'Space default state' => '',
  'Spaces' => 'Forum',
  'This module doesn\'t provide further information.' => 'Denna modul ger ingen ytterligare information.',
  'Try other keywords or remove filters.' => 'Prova andra sökord eller ta bort filter.',
  'Update successful' => '',
  'User default state' => '',
  'Users' => 'Användare',
);
